summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--init.lua8
1 files changed, 5 insertions, 3 deletions
diff --git a/init.lua b/init.lua
index 2726aa9..4493975 100644
--- a/init.lua
+++ b/init.lua
@@ -331,9 +331,11 @@ end
-- Freeform text
doc.entry_builders.text = function(data)
- -- TODO: Wait for Minetest to provide a native widget for scrollable read-only text with automatic line breaks
- -- Currently, all of this had to be hacked into this script manually by using/abusing the textlis widget
- return "textlist[0,0.5;11.8,8;text;"..text_for_textlist(data)..";1;true]"
+ -- TODO: Wait for Minetest to provide a native widget for scrollable read-only text with automatic line breaks.
+ -- Currently, all of this had to be hacked into this script manually by using/abusing the table widget
+ return "tablecolumns[text]"..
+ "tableoptions[background=#00000000;highlight=#00000000;border=false]"..
+ "table[0,0.5;11.8,8;text;"..text_for_textlist(data).."]"
end
-- Direct formspec